oumi.models.experimental.cambrian.model.language\_model.phi3
============================================================
.. automodule:: oumi.models.experimental.cambrian.model.language_model.phi3
   :members:
   :undoc-members:
   :show-inheritance:
